@@ -1,10 +1,20 @@
 package Alien::WFDB;
-$Alien::WFDB::VERSION = '0.002';
+$Alien::WFDB::VERSION = '0.003';
 use strict;
 use warnings;
 
 use parent 'Alien::Base';
 
+sub Inline {
+	return unless $_[-1] eq 'C'; # Inline's error message is good
+	my $self = __PACKAGE__->new;
+	+{
+		LIBS => $self->libs,
+		INC => $self->cflags,
+		AUTO_INCLUDE => '#include "wfdb.h"',
+	};
+}
+
 1;
 # ABSTRACT: Alien package for the WFDB (WaveForm DataBase) library
 
@@ -20,7 +30,11 @@ Alien::WFDB - Alien package for the WFDB (WaveForm DataBase) library
 
 =head1 VERSION
 
-version 0.002
+version 0.003
+
+=head1 Inline support
+
+This module supports L<Inline's with functionality|Inline/"Playing 'with' Others">.
 
 =head1 SEE ALSO
 
